@@ -1,11 +1,9 @@
 package Config::IniFiles::Check::Health;
 use 5.006;
-use Moo 2.005_001;
+use Moo 2.004000;
 use strictures 2;
 use namespace::clean;
-use Params::Validate qw(validate_with OBJECT SCALAR ARRAYREF UNDEF);
-
-
+use Params::Validate 1.30 qw(validate_with OBJECT SCALAR ARRAYREF UNDEF);
 
 =head1 NAME
 
@@ -13,11 +11,11 @@ Config::IniFiles::Check::Health - check ini-files for needed values
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
@@ -126,13 +124,13 @@ sub _check_new_params {
     my @all_params_must    = qw( logger ini_obj);
     my $params_wanted_href = { map { $_ => $self->$_ } @all_params_must };
 
-    my $params_spec = { 
+    my $params_spec = {
         logger => {
             type => UNDEF | OBJECT,
         },
         ini_obj => {
             type => OBJECT,
-            isa => "Config::IniFiles"
+            isa  => "Config::IniFiles"
         },
     };
 
@@ -157,23 +155,27 @@ from the ini-file.
 =cut
 
 has 'logger' => (
-    is => 'ro',
+    is  => 'ro',
     isa => sub {
+
         # undef is ok
-        if (! defined($_[0])) {
+        if ( !defined( $_[0] ) ) {
             return;
-        } elsif (ref($_[0]) eq  'Config::IniFiles') {
+        }
+        elsif ( ref( $_[0] ) eq 'Config::IniFiles' ) {
             return;
-        } else {
-            die "logger must be undef or of type Log::Log4perl"    
+        }
+        else {
+            die "logger must be undef or of type Log::Log4perl";
         }
     },
 );
 
 has 'ini_obj' => (
-    is => 'ro',
+    is  => 'ro',
     isa => sub {
-        die "ini_obj must be of type Config::IniFiles" unless ref($_[0]) eq  'Config::IniFiles'
+        die "ini_obj must be of type Config::IniFiles"
+          unless ref( $_[0] ) eq 'Config::IniFiles';
     },
 );
 
@@ -189,7 +191,7 @@ You can switch behaviour of the following tests:
 =cut
 
 has 'errors_are_fatal' => (
-    is => 'rw',
+    is      => 'rw',
     default => sub { 1 },
 );
 
@@ -200,11 +202,12 @@ has 'errors_are_fatal' => (
 =cut
 
 sub check_for_duplicate_vars_in_all_sections {
-    my $self = shift;
-    my $logger = $self->logger;
+    my $self    = shift;
+    my $logger  = $self->logger;
     my $ini_obj = $self->ini_obj;
-    for my $cur_section ($ini_obj->Sections) {
-        $self->check_for_duplicate_vars_in_one_section({ section => $cur_section });
+    for my $cur_section ( $ini_obj->Sections ) {
+        $self->check_for_duplicate_vars_in_one_section(
+            { section => $cur_section } );
     }
 }
 
@@ -225,35 +228,38 @@ Usage:
 =cut
 
 sub check_for_duplicate_vars_in_one_section {
-    my $self = shift;
+    my $self      = shift;
     my $args_href = validate_with(
         params => shift,
-        spec => {
+        spec   => {
             section => {
                 type => SCALAR,
             },
         }
     );
-    my $logger = $self->logger;
+    my $logger  = $self->logger;
     my $ini_obj = $self->ini_obj;
     my $section = $args_href->{section};
     my $log_msg;
     my $nr_of_errors = 0;
 
-    for my $current_varname ($ini_obj->Parameters($section)) {
+    for my $current_varname ( $ini_obj->Parameters($section) ) {
+
         # List context gives an element per line:
-        my @all_values = $ini_obj->val($section, $current_varname);
-        if (@all_values > 1) {
+        my @all_values = $ini_obj->val( $section, $current_varname );
+        if ( @all_values > 1 ) {
             $nr_of_errors++;
-            $log_msg = sprintf "Found duplicate line in section '%s' with varname='%s'",
-                $section,
-                $current_varname;
+            $log_msg =
+              sprintf "Found duplicate line in section '%s' with varname='%s'",
+              $section,
+              $current_varname;
             $self->_log_error($log_msg);
         }
     }
 
-    if ($self->errors_are_fatal && $nr_of_errors > 0) {
-        $log_msg = sprintf 'Too many errors in check_for_duplicate_vars_in_section';
+    if ( $self->errors_are_fatal && $nr_of_errors > 0 ) {
+        $log_msg =
+          sprintf 'Too many errors in check_for_duplicate_vars_in_section';
         $self->_log_fatal($log_msg);
     }
 }
@@ -265,40 +271,40 @@ sub check_for_duplicate_vars_in_one_section {
     });
 
 =cut
-    
+
 sub check_for_sections {
-    my $self = shift;
+    my $self      = shift;
     my $args_href = validate_with(
         params => shift,
-        spec => {
+        spec   => {
             sections_must_exist => {
                 type => ARRAYREF,
             },
         }
     );
-    my $logger = $self->logger;
-    my $ini_obj = $self->ini_obj;
-    my @sections_must_exist = @{$args_href->{sections_must_exist}};
+    my $logger              = $self->logger;
+    my $ini_obj             = $self->ini_obj;
+    my @sections_must_exist = @{ $args_href->{sections_must_exist} };
 
     my $errors_are_fatal = $args_href->{errors_are_fatal};
     my $log_msg;
     my $nr_of_errors = 0;
 
     for my $section_name (@sections_must_exist) {
-        if (! $ini_obj->SectionExists($section_name)) {
+        if ( !$ini_obj->SectionExists($section_name) ) {
             $nr_of_errors++;
-            $log_msg = sprintf "Section '%s' does not exist in inifile", $section_name;
+            $log_msg = sprintf "Section '%s' does not exist in inifile",
+              $section_name;
             $self->_log_error($log_msg);
         }
     }
 
-    if ($self->errors_are_fatal && $nr_of_errors > 0) {
+    if ( $self->errors_are_fatal && $nr_of_errors > 0 ) {
         $log_msg = sprintf 'Too many errors in check_inifile_for_sections';
         $self->_log_fatal($log_msg);
     }
 }
 
-
 =head2 check_inifile_for_values
 
     $ini_health_checker_obj->check_inifiles_for_values({
@@ -311,35 +317,37 @@ sub check_for_sections {
 =cut
 
 sub check_inifile_for_values {
-    my $self = shift;
+    my $self      = shift;
     my $args_href = validate_with(
         params => shift,
-        spec => {
+        spec   => {
             values_must_exist => {
                 type => ARRAYREF,
             },
         }
     );
-    my $logger = $self->logger;
-    my $ini_obj = $self->ini_obj;
-    my @values_must_exist = @{$args_href->{values_must_exist}};
-    my $errors_are_fatal = $args_href->{errors_are_fatal};
+    my $logger            = $self->logger;
+    my $ini_obj           = $self->ini_obj;
+    my @values_must_exist = @{ $args_href->{values_must_exist} };
+    my $errors_are_fatal  = $args_href->{errors_are_fatal};
 
     my $nr_of_errors = 0;
     my $log_msg;
 
     for my $values_must_exist_href (@values_must_exist) {
-        my $section = $values_must_exist_href->{section};
-        my $varname = $values_must_exist_href->{varname};
-        my $value_from_inifile = $ini_obj->val($section, $varname);
-        if (! defined $value_from_inifile) {
+        my $section            = $values_must_exist_href->{section};
+        my $varname            = $values_must_exist_href->{varname};
+        my $value_from_inifile = $ini_obj->val( $section, $varname );
+        if ( !defined $value_from_inifile ) {
             $nr_of_errors++;
-            $log_msg = sprintf "value MUST exist in inifile, but does not: section='%s', value='%s'",
-                $section, $varname;
+            $log_msg =
+              sprintf
+"value MUST exist in inifile, but does not: section='%s', value='%s'",
+              $section, $varname;
             $self->_log_error($log_msg);
         }
     }
-    if ($self->errors_are_fatal && $nr_of_errors > 0) {
+    if ( $self->errors_are_fatal && $nr_of_errors > 0 ) {
         $log_msg = 'Too many errors in check_inifile_for_values';
         $self->_log_fatal($log_msg);
     }
@@ -352,13 +360,14 @@ sub check_inifile_for_values {
 =cut
 
 sub _log_error {
-    my $self = shift;
+    my $self    = shift;
     my $log_msg = shift;
-    my $logger = $self->logger;
+    my $logger  = $self->logger;
 
     if ($logger) {
         $logger->error($log_msg);
-    } else {
+    }
+    else {
         printf "ERROR - %s\n", $log_msg;
     }
 }
@@ -373,21 +382,21 @@ sub _log_error {
 =cut
 
 sub _log_fatal {
-    my $self = shift;
+    my $self    = shift;
     my $log_msg = shift;
-    my $logger = $self->logger;
-    
+    my $logger  = $self->logger;
+
     if ($logger) {
         $logger->error($log_msg);
-    } else {
+    }
+    else {
         print "ERROR - $log_msg\n";
     }
-    if ($self->errors_are_fatal) {
+    if ( $self->errors_are_fatal ) {
         die $log_msg;
     }
 }
 
-
 =head1 AUTHOR
 
 Richard Lippmann, C<< <horshack at cpan.org> >>
